@@ -6,13 +6,13 @@ init <- function(size = "small") {
   if (!kiwi_model_exists(size))
     get_kiwi_models(size)
 
-  kb <- kiwi_init_(kiwi_model_path_full(size), 0, BuildOpt$DEFAULT)
+  kw <- kiwi_init_(kiwi_model_path_full(size), 0, BuildOpt$DEFAULT)
   err <- kiwi_error_wrap()
 
   if (!is.null(err))
     stop(err)
 
-  assign("kb", kb, envir = .el)
+  assign("kw", kw, envir = .el)
 }
 
 
